# BSK-RL: Environments for Spacecraft Planning and Scheduling

<img align="right" src="./docs/source/_images/static/bsk_rl-logo.png" width=180px>


[BSK-RL](https://avslab.github.io/bsk_rl/) ([Basilisk](https://hanspeterschaub.info/basilisk) + [Reinforcement Learning](https://en.wikipedia.org/wiki/Reinforcement_learning)) is a Python package for constructing [Gymnasium](https://gymnasium.farama.org/index.html) environments for spacecraft tasking problems. It is built on top of [Basilisk](https://hanspeterschaub.info/basilisk), a modular and fast spacecraft simulation framework, making the simulation environments high-fidelity and computationally efficient. 

### Usage
Installation instructions, examples, and documentation can be found on the [BSK-RL website](https://avslab.github.io/bsk_rl/).

### Acknowledgment

BSK-RL is developed by the [Autonomous Vehicle Systems (AVS) Lab](https://hanspeterschaub.info/AVSlab.html) at the University of Colorado Boulder.

